==> sddm_0.14.0.orig.tar.gz: sddm-0.14.0/data/translations/uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Ласкаво просимо до %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Увага, увімкнутий Caps Lock!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Розкладка клавіатури</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вхід</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Помилка входу</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Вдалось увійти</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Введіть ім'я користувача та пароль</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Сесія</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Ім'я користувача/translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Оберіть користувача та введіть пароль</translation>
    </message>
</context>
</TS>

==> sddm_0.17.0.orig.tar.gz: sddm-0.17.0/data/translations/uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Ласкаво просимо до %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Увага, увімкнутий Caps Lock!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Розкладка клавіатури</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вхід</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Помилка входу</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Вдалось увійти</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Введіть ім'я користувача та пароль</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Сесія</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Ім'я користувача</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Оберіть користувача та введіть пароль</translation>
    </message>
</context>
</TS>
